Outsider
========

This project is a GUI interface for controlling the Blackstar ID series of
amplifiers. The software is still in development, but should be usable as a
replacement for most of the functionality of the Insider software that Blackstar
ship.

